---
title: MkDocs Tech Docs Template
hide:
  - navigation
  - toc
---

<style>
  .md-typeset h1 {
    display: none;
  }
  
  .md-main__inner {
    margin-top: 0px;
  }

  .md-content__button {
    display: none;
  }
</style>

!!! banner "Build flexible technical documentation with a [GOV.UK style](https://design-system.service.gov.uk/)"

    ![Services](homepage-illustration.svg){ align=right width=300px height=300px}

    **Mkdocs Tech Docs Template** is a python-based alternative to the ruby-based [Tech Docs Template](https://github.com/alphagov/tech-docs-template) with the following benefits:

    - simple to [setup](./setup/), [customise](./setup/customise.md) and [enhance](./setup/CONTRIBUTE.md)
    - exploits the [MkDocs Materials theme](https://squidfunk.github.io/mkdocs-material/) and all it's associated features
    - compatible with the vast ecosystem of MkDocs [plugins](plugins/)
    - unified tech stack for python-based teams and projects

    [Get Started ＞](./setup/){ .md-button .md-button--primary}

!!! warning inline end "Prototype"

    This template is under construction and should only be used for prototyping
    
!!! quote "Restrictions"

    You’re welcome to use the MkDocs Tech Docs Template even if your service isn’t considered part of GOV.UK, but your site or service must not:

    - identify itself as being part of GOV.UK
    - use the crown or GOV.UK logotype in the header
    - use the GDS Transport typeface
    - suggest that it’s an official UK government website if it’s not

<br>
